#include <targets/aduc7020.h>
#include <string.h>      // Stingfunktionen
#include "../header/lcdspi.h"
#include "../header/system.h"

// Vernderliche Variablen
//*******************************************
#define VOLTAGE  3     // Voltage auf 5 oder 3 Volt
#define CONTRAST 0x7A  // Von 0x73 bis 0x7F Hexadezimal
//*******************************************

void Disp_Command(int Data)
{

  // Command Mode vorbeireiten; setze RS low
  lcd_clear_rs_spi();
  lcd_clear_cs_spi();

  //set data to transfer
  SPIYX = Data & 0xFF;
  // Wait for the transfer to complete
  while(!(SPISTA&0x08));

  //bertragung abschlieen durch RS toggle
  
  lcd_set_rs_spi(); // high
  timer_us(1);
  lcd_clear_rs_spi(); //low
  
  lcd_set_cs_spi();

  timer_ms(10); // warte auf Display
}



void Disp_Byte(int Data)
{
  // Data Mode vorbeireiten; setze RS high
  lcd_set_rs_spi();
  lcd_clear_cs_spi();

  //set data to transfer
  SPIYX = Data & 0xFF;
  // Wait for the transfer to complete
  while(!(SPISTA&0x08));

  //bertragung abschlieen durch RS toggle
  lcd_clear_rs_spi(); //low
  timer_us(1); // warte auf Display
  lcd_set_rs_spi(); // high

  lcd_set_cs_spi();
  timer_ms(10); // warte auf Display
}



void Disp_Char(char cData)
{
  // Data Mode vorbeireiten; setze RS high
  lcd_set_rs_spi();
  lcd_clear_cs_spi();

  //set data to transfer
  SPIYX = cData & 0xFF;
  // Wait for the transfer to complete
  while(!(SPISTA&0x08));
  
  //bertragung abschlieen durch RS toggle
  lcd_clear_rs_spi(); //low
  timer_us(1); // warte auf Display
  lcd_set_rs_spi(); // high
  
  lcd_set_cs_spi();

  timer_ms(10); // warte auf Display
}



void Disp_String(char *cData)
{
  // Data Mode vorbeireiten; setze RS high
  lcd_set_rs_spi();
  
  while (*cData)
  {
    lcd_clear_cs_spi();
    //set data to transfer
    SPIYX = *cData & 0xFF;
    // Wait for the transfer to complete
    while(!(SPISTA&0x08));
  
    //bertragung abschlieen durch RS toggle
    lcd_clear_rs_spi(); //low
    timer_us(1); // warte auf Display
    lcd_set_rs_spi(); // high
    
    lcd_set_cs_spi();

    timer_ms(10); // warte auf Display
    ++cData;
  }
}

void Disp_Clear(void)
{

  Disp_Command(0x01); // Disoplay lschen
  timer_ms(50);      // Auf Display warten
  Disp_Command(0x06); // Entry Mode set - Display wartet auf Eingabe
  timer_ms(50);      // Auf Display warten

}

void Disp_Init(void)
{
        
  lcd_clear_rs_spi();
  lcd_clear_cs_spi();

  timer_s(3); // Warte auf Display
  
  int BIAS,PWR,FOLLOW;
  
  if (VOLTAGE == 5)
          {
           BIAS = 0x1c;
           PWR  = 0x51;
           FOLLOW = 0x6a; 
          }
  else
          {
           BIAS = 0x14;
           PWR  = 0x55;
           FOLLOW = 0x6d;
          }
  
  Disp_Command(0x31); // Function Set ; 8 Bit; 1Zeile, Istr.Tab 1
  Disp_Command(BIAS); // Bias Set 
  Disp_Command(PWR); // Power Controll
  Disp_Command(0x6a); // Follower Controll
  Disp_Command(CONTRAST); // Kontrast setzten
  Disp_Command(0x30); // Instruction Table 0 setzten
  Disp_Command(0x0F); // Display ein, Cursor ein ,Blinken
  Disp_Command(0x01); // Disoplay lschen
  timer_ms(50);      // Auf Display warten
  Disp_Command(0x06); // Entry Mode set - Display wartet auf Eingabe
  timer_ms(50);      // Auf Display warten

}
