#include <targets/aduc7020.h>
#include <ctl_api.h>
#include "../header/system.h"
#include "../header/lcd4bit.h"
#include "../header/lcdspi.h"


/**
* How to calculate 
* 
*The formel : T = (T2LD * prescaler)/Corefrequence
*             1s = (T2LD*x)/y => find T2LD where x & y are known.
*             and set it as the constant for sConstant...
*/
 
#define sConstant  0x9F4D40 //10440000 for seconds
#define msConstant 0x28C8   //10440 for ms
#define usConstant 0xB      //11 for 1,0536398467432950191570881226054us

//Frequenz initialisierung
void System_Init_FREQ(void)
{
  PLLKEY1 = 0xAA;
  PLLCON = 0x21;                     //PLL Default configuration, internal 32 kHz oscillator
  PLLKEY2 = 0x55;
  
  POWKEY1 = 0x01;
  POWCON = 0x02;                     // CPU clock divider bits ==> 10,44MHz
  POWKEY2 = 0xF4;
}

//GPIO Konfiguration
void System_Init_GPIO(void)
{
  /**
  **P1.0, P1.1, P1.2, P1.3 Configured as GPIO (00 bits)
  **/
  GP1CON = 0x00000000;
  
  /**
  **bit 31 : RS <=> P1.7 Dir : output
  **bit 30 : E  <=> P1.6 Dir : output
  **bit 29 : 4-Bits <=> P1.5 Dir : output
  **bit 28 : RW <=> P1.4 Dir : output
  **bit 27 : DB7 <=> P1.3 Dir : output
  **bit 26 : DB6 <=> P1.2 Dir : output
  **bit 25 : DB5 <=> P1.1 Dir : output
  **bit 24 : DB4 <=> P1.0 Dir : output
  **/
  GP1DAT = 0xFF000000;                         
  GP1SET = 0x00000000;
}

// Init SPI interface
void System_Init_SPI(void)
{

  // MOSI,CLK and CS as output //P1.0 P1.1 as output
  GP1DAT = 0xD3000000;
  
  // Pins as SPI port  //Pins 1.0 1.1 as GPIO
  GP1CON = 0x22220000;
  
  // Master mode, no phase, no polarity, MSB first, Enable SPI, loopback aus
  SPICON = 0x0043; 
  
  // Set devider for SPI ~ 100kHz
  SPIDIV = 0x17;

  __disable_interrupt();

}

// Transmit one byte via SPI
unsigned char SPITransmit(unsigned char ch) {

  unsigned char data;

  // Wait until transmit is under flowing
  while((SPISTA&0x04));
  // Send the data
  SPIYX = ch;


  // Wait for the transfer to complete
  while(!(SPISTA&0x08));
  // Get the data received
  data = SPIRX;

  return data;

}

void ADCPOWERON(int time)
{
  ADCCON =0x20;            // ADC Einschalten
  while(time>=0)            // wait for DAC to be fully powered on   
  time--;
}

void System_Init_ADC(void)
{
  ADCPOWERON(20000);       // ADC Einschalten
  DAC0CON =0x13  ;          //Enable DAC0  0V to AVDD Range

  ADCCP = 0x00;         //ADC0
  ADCCON = 0xAC;        //0xACfully Differential mode mode, continuous software conv., conv. enabled
  REFCON = 0x01;      //Interne Referenzspannng 2,5V
}

void checkSPI(void){
  lcd_clear_rs_spi();
  lcd_set_rs_spi();

  lcd_clear_rs_spi();
  lcd_set_rs_spi();

  lcd_clear_rs_spi();


  lcd_set_cs_spi();
  lcd_clear_cs_spi();

  lcd_set_cs_spi();
  lcd_clear_cs_spi();

  lcd_clear_cs_spi();

}

void delay(unsigned long a){
  a = 500000;
  while(a){
    a--;
    }
}

void check4bit(void){
  /*Checking RW*/
  lcd_set_rw();
  lcd_clear_rw();
  lcd_set_rw();
  lcd_clear_rw();

  /*Checkung RS*/
  lcd_set_rs();
  lcd_clear_rs();
  lcd_set_rs();
  lcd_clear_rs();

  /*Checking E*/
  lcd_set_e();
  lcd_clear_e();
  lcd_set_e();
  lcd_clear_e();
}


void timer(unsigned int value){
  T2CON = 0;
  T2CLRI = 0;
  T2LD = value;
  T2CON = 0x6C0; // prescaler 1 ,enable Timer 2, periodic mode, using iternal clock (see init_freq)
  while (!(IRQSIG & IRQSIG_Wake_Up_Timer)); // wait for timeout
  T2CON = 0; // disable Timer 2
}

void timer_s(unsigned int seconds){
  timer(sConstant*seconds);
}

void timer_ms(unsigned int miliseconds){
  timer(msConstant*miliseconds);
}

void timer_us(unsigned int microseconds){
  timer(usConstant*microseconds); 
}

void testTimer(){
   lcd_set_LED();

   timer_us(1000000);
   
   lcd_clear_LED();

   timer_ms(1000);
   
}
